@@ -75,12 +75,26 @@ class JobOutput:
                message = "getDaxExecutables: %s file could not be parsed" % (daxPath)
                self.logger.log(logging.ERROR,getLogMessage(message))
             else:
-               tc = daxDoc['transformationCatalog']
-               for transformation in tc['transformations']:
-                  for site in transformation['sites']:
-                     if site['name'] == 'local':
-                        executablePath = site['pfn']
-                        daxExecutables.append(executablePath)
+               try:
+                  tc = daxDoc['transformationCatalog']
+               except KeyError:
+                  pass
+               else:
+                  try:
+                     transformations = tc['transformations']
+                  except KeyError:
+                     pass
+                  else:
+                     for transformation in transformations:
+                        try:
+                           sites = transformation['sites']
+                        except KeyError:
+                           pass
+                        else: 
+                           for site in sites:
+                              if site['name'] == 'local':
+                                 executablePath = site['pfn']
+                                 daxExecutables.append(executablePath)
          else:
             self.logger.log(logging.ERROR,getLogMessage("dax %s file has unrecognized format" % (daxPath)))
       else:
@@ -618,7 +632,7 @@ class JobOutput:
 #                                                                 headers[columnRuntime])
 #                          self.logger.log(logging.DEBUG,getLogMessage(message))
 
-                           jobPattern = re.compile('(([^_]*)_)?([0-9]*)_([0-9]*)[\.|_]sh_([^_]*)_([0-9]*)(.*)')
+                           jobPattern = re.compile(r'(([^_]*)_)?([0-9]*)_([0-9]*)[\.|_]sh_([^_]*)[\-_]([0-9]*)(.*)')
                            for row in csvReader:
                               try:
                                  exitStatus = int(float(row[columnExitcode]))
